.. module:: bana.OpenMaya.MObject

.. _openmaya_mobject:

OpenMaya.MObject
================

.. autosummary::
   :nosignatures:

   ~MObject.bnFind
   ~MObject.bnGet
   ~MObject.__hash__


----

.. automethod:: MObject.bnFind

----

.. automethod:: MObject.bnGet

----

.. automethod:: MObject.__hash__
